/*
File Name: RTC
 Contents: Code for managing initial RTC setting and getting time/date for logging.  Based on LadyAda logger code examples.
 See www.adafruit.com for information.
 Last modified: 1/5/11
 Programmer: John Vaughn
 */
 
// Defines used here for various devices we will be addressing, etc.
#define DS1307_I2C_ADDRESS 0x68

// Convert normal decimal numbers to binary coded decimal
byte decToBcd(byte val)
{
  return ( (val/10*16) + (val%10) );
}  // End decToBcd

// Convert binary coded decimal to normal decimal numbers
byte bcdToDec(byte val)
{
  return ( (val/16*10) + (val%16) );
}  // End bcdToDec

void setDateDs1307(
byte second,        // 0-59
byte minute,        // 0-59
byte hour,          // 1-23
byte dayOfWeek,     // 1-7
byte dayOfMonth,    // 1-28/29/30/31
byte month,         // 1-12
byte year)          // 0-99
{
  Wire.beginTransmission(DS1307_I2C_ADDRESS);
  Wire.send(0);
  Wire.send(decToBcd(second));    // 0 to bit 7 starts the clock
  Wire.send(decToBcd(minute));
  Wire.send(decToBcd(hour));      // If you want 12 hour am/pm you need to set
                                  // bit 6 (also need to change readDateDs1307)
  Wire.send(decToBcd(dayOfWeek));
  Wire.send(decToBcd(dayOfMonth));
  Wire.send(decToBcd(month));
  Wire.send(decToBcd(year));
  Wire.endTransmission();
}  // End setDate1307

// Gets the date or time from the ds1307.  We put the resulting date/time parts into 
// our parameter array to pass them back to the calling function.  
void getDateTime(int dateTime[]){
  byte second, minute, hour, dayOfWeek, dayOfMonth, month, year;
  
  // Reset the register pointer
  Wire.beginTransmission(DS1307_I2C_ADDRESS);
  Wire.send(0);
  Wire.endTransmission();
  Wire.requestFrom(DS1307_I2C_ADDRESS, RTC_PIN);
  
  // A few of these need masks because certain bits are control bits
  second     = bcdToDec(Wire.receive() & 0x7f);
  minute     = bcdToDec(Wire.receive());
  hour       = bcdToDec(Wire.receive() & 0x3f);  // Need to change this if 12 hour am/pm
  dayOfWeek  = bcdToDec(Wire.receive());
  dayOfMonth = bcdToDec(Wire.receive());
  month      = bcdToDec(Wire.receive());
  year       = bcdToDec(Wire.receive());

  dateTime[0] = (int) second;
  dateTime[1] = (int) minute;
  dateTime[2] = (int) hour;
  dateTime[3] = (int) dayOfWeek;
  dateTime[4] = (int) dayOfMonth;
  dateTime[5] = (int) month;
  dateTime[6] = (int) year;
}  // End of getDateTime

// End file RTC



